@@ -15,7 +15,6 @@
 #include "umllistviewitem.h"
 #include "umlobject.h"
 #include "widgetbase.h"
-
 #include <kmenu.h>
 
 #include <QHash>
@@ -55,6 +54,7 @@ public:
         mt_UseCase_Diagram,
         mt_Sequence_Diagram,
         mt_Class_Diagram,
+        mt_Object_Diagram,
         mt_Collaboration_Diagram,
         mt_State_Diagram,
         mt_Activity_Diagram,
@@ -64,6 +64,7 @@ public:
         mt_On_UseCase_Diagram,
         mt_On_Sequence_Diagram,
         mt_On_Class_Diagram,
+        mt_On_Object_Diagram,
         mt_On_Collaboration_Diagram,
         mt_On_State_Diagram,
         mt_On_Activity_Diagram,
@@ -85,11 +86,13 @@ public:
         mt_Interface,
         mt_Enum,
         mt_Entity,
+        mt_Instance,
         mt_Datatype,
         mt_Actor,
         mt_UseCase,
         mt_Attribute,
         mt_EntityAttribute,
+        mt_InstanceAttribute,
         mt_EnumLiteral,
         mt_UniqueConstraint,
         mt_PrimaryKeyConstraint,
@@ -117,6 +120,7 @@ public:
         mt_New_Parameter,
         mt_New_Operation,
         mt_New_Attribute,
+        mt_New_InstanceAttribute,
         mt_New_Template,
         mt_New_EnumLiteral,
         mt_New_EntityAttribute,
@@ -127,6 +131,7 @@ public:
         mt_Parameter_Selected,
         mt_Operation_Selected,
         mt_Attribute_Selected,
+        mt_InstanceAttribute_Selected,
         mt_Template_Selected,
         mt_EnumLiteral_Selected,
         mt_EntityAttribute_Selected,
@@ -138,6 +143,7 @@ public:
         mt_Show_Attributes,                      // Toggle visual property on a widget
         mt_Show_Attributes_Selection,            // Set visual property on multiple widgets
         mt_Hide_Attributes_Selection,            // Unset visual property on multiple widgets
+        mt_Show_Documentation,
         mt_Show_Operations,                      // Toggle 'show operations'
         mt_Show_Operations_Selection,            // Show operations
         mt_Hide_Operations_Selection,            // Hide operations
@@ -164,10 +170,19 @@ public:
         mt_ChangeToClass,
         mt_ChangeToInterface,
         mt_ChangeToPackage,
+        mt_ChangeToInstance,
         mt_Rename_Object,
         mt_Select_Operation,
         mt_Anchor,
         mt_Properties,
+        mt_Properties_AutoLayout,
+        mt_Properties_Class,
+        mt_Properties_CodeImport,
+        mt_Properties_CodeGeneration,
+        mt_Properties_CodeViewer,
+        mt_Properties_Font,
+        mt_Properties_General,
+        mt_Properties_UserInterface,
         mt_Rename,
         mt_NameAsTooltip,
         mt_Show,
@@ -210,8 +225,10 @@ public:
         mt_Change_Font,
         mt_Change_Font_Selection,
         mt_SnapToGrid,
+        mt_SnapComponentSizeToGrid,
         mt_ShowDocumentationIndicator,
         mt_ShowSnapGrid,
+        mt_AutoResize,
         mt_Resize,
         mt_Activity_Selected,
         mt_New_Activity,
@@ -256,6 +273,7 @@ public:
         mt_Align_HorizontalMiddle,
         mt_Align_VerticalDistribute,
         mt_Align_HorizontalDistribute,
+        mt_Import_from_File,
 
         mt_Undefined  =  - 1
     };
@@ -299,14 +317,16 @@ private:
 
     void insert(MenuType m);
     void insert(const MenuType m, KMenu* menu);
-    void insert(const MenuType m, const QIcon & icon, const QString & text);
-    void insert(const MenuType m, const QString & text, const bool checkable = false);
     void insert(const MenuType m, KMenu* menu, const QIcon & icon, const QString & text);
     void insert(const MenuType m, KMenu* menu, const QString & text, const bool checkable = false);
+    void insert(const MenuType m, const QIcon & icon, const QString & text);
+    void insert(const MenuType m, const QString & text, const bool checkable = false);
+
 
     void insertStdItems(bool insertLeadingSeparator = true,
                         WidgetBase::WidgetType type = WidgetBase::wt_UMLWidget);
-    void insertContainerItems(bool folderAndDiagrams);
+    void insertContainerItems(bool folderAndDiagrams, bool packages=true);
+    void insertContainerItems(KMenu* menu, bool folderAndDiagrams, bool packages);
     void insertAssociationItem(MenuType mt);
     void insertAssociationTextItem(const QString &label, MenuType mt);
     void insertSubMenuLayout(AssociationLine *associationLine);
@@ -319,6 +339,7 @@ private:
     KMenu* makeCategoryTypeMenu(UMLCategory* category);
 
     void insertSubMenuNew(MenuType type);
+    void insertSubMenuShowEntity(EntityWidget *widget);
     void insertSubMenuAlign();
     void insertSubMenuColor(bool fc);
 
