@@ -17,6 +17,7 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QMap>
+#include <QPointer>
 #include <QTreeWidget>
 
 // forward declarations
@@ -98,6 +99,9 @@ public:
         lvt_Properties_General,
         lvt_Properties_UserInterface,
         lvt_Association,
+        lvt_Object_Diagram,
+        lvt_Instance,
+        lvt_InstanteAttribute,
         lvt_Unknown = -1
     };
 
@@ -146,8 +150,8 @@ public:
 
     UMLListViewItem* childItem(int i);
 
-    void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
-    bool loadFromXMI(QDomElement& qElement);
+    void saveToXMI1(QDomDocument& qDoc, QDomElement& qElement);
+    bool loadFromXMI1(QDomElement& qElement);
 
     bool isOpen() { return isExpanded(); }
     void setOpen(bool state);
@@ -170,7 +174,7 @@ protected:
 
     ListViewType       m_type;
     Uml::ID::Type      m_id;
-    UMLObject *        m_object;
+    QPointer<UMLObject> m_object;
     QString            m_label;
     ChildObjectMap     m_comap;
 
